struct s
(
	tTooltip = "Too high subdivs in vray materials can slow down your rendering.",
	nMaxSubdivs = 8,
	tName = "Refl./Refr. Subdivs > "+ nMaxSubdivs as string,
	
	fn matIsReflecting mat = if mat.texmap_reflection != undefined and mat.texmap_reflection_on then true else mat.reflection != black,
	fn matIsRefracting mat = if mat.texmap_refraction != undefined and mat.texmap_refraction_on then true else mat.refraction != black,
	
	
	fn enabled =
	(
		vray != undefined
	),

	fn count =
	(
		local nCount = 0
		
		for mat in (getclassinstances VrayMtl)
			where (matIsReflecting mat or matIsRefracting mat) and (mat.reflection_subdivs > nMaxSubdivs or mat.refraction_subdivs > nMaxSubdivs)
			do nCount += 1
		
		nCount
	),

	fn clean =
	(	
		for mat in (getclassinstances VrayMtl) do
		(
			if matIsReflecting mat and mat.reflection_subdivs > nMaxSubdivs then mat.reflection_subdivs = nMaxSubdivs
			if matIsRefracting mat and mat.refraction_subdivs > nMaxSubdivs then mat.refraction_subdivs = nMaxSubdivs
		)
	),
	
	fn selectObjects =
	(		
		local lObjs = #()
		for mat in (getclassinstances VrayMtl) do
		(
			if (matIsReflecting mat or matIsRefracting mat) and (mat.reflection_subdivs > nMaxSubdivs or mat.refraction_subdivs > nMaxSubdivs) then
				for obj in (refs.dependents mat) where classof (superclassof obj) == node and (obj as string)[1] == "$" do appendIfUnique lObjs obj
		)
		
		select lObjs
		local bRefreshSel = false
		for obj in selection do
		(
			if isGroupHead obj and not isOpenGroupHead obj then
			(
				bRefreshSel = true
				setGroupOpen obj true
			)
		)
		if bRefreshSel then select lObjs
	),
	
	fn selectMaterials =
	(		
		local lMats = #()
		
		for mat in (getclassinstances VrayMtl) do
		(
			if (matIsReflecting mat or matIsRefracting mat) and (mat.reflection_subdivs > nMaxSubdivs or mat.refraction_subdivs > nMaxSubdivs) then
				appendIfUnique lMats mat
		)
		
		for nMat = 1 to lMats.count where nMat <= meditMaterials.count do setMeditMaterial nMat lMats[nMat]
	)
)
